@@ -6,9 +6,9 @@ Type annotations for dataexchange service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_dataexchange.type_defs import AssetDestinationEntryTypeDef
+    from mypy_boto3_dataexchange.type_defs import ActionTypeDef
 
-    data: AssetDestinationEntryTypeDef = {...}
+    data: ActionTypeDef = {...}
     ```
 """
 import sys
@@ -36,13 +36,18 @@ else:
 
 
 __all__ = (
+    "ActionTypeDef",
     "AssetDestinationEntryTypeDef",
     "AssetDetailsTypeDef",
     "AssetEntryTypeDef",
     "AssetSourceEntryTypeDef",
+    "AutoExportRevisionDestinationEntryTypeDef",
+    "AutoExportRevisionToS3RequestDetailsTypeDef",
     "CancelJobRequestRequestTypeDef",
     "CreateDataSetRequestRequestTypeDef",
     "CreateDataSetResponseTypeDef",
+    "CreateEventActionRequestRequestTypeDef",
+    "CreateEventActionResponseTypeDef",
     "CreateJobRequestRequestTypeDef",
     "CreateJobResponseTypeDef",
     "CreateRevisionRequestRequestTypeDef",
@@ -50,8 +55,11 @@ __all__ = (
     "DataSetEntryTypeDef",
     "DeleteAssetRequestRequestTypeDef",
     "DeleteDataSetRequestRequestTypeDef",
+    "DeleteEventActionRequestRequestTypeDef",
     "DeleteRevisionRequestRequestTypeDef",
     "DetailsTypeDef",
+    "EventActionEntryTypeDef",
+    "EventTypeDef",
     "ExportAssetToSignedUrlRequestDetailsTypeDef",
     "ExportAssetToSignedUrlResponseDetailsTypeDef",
     "ExportAssetsToS3RequestDetailsTypeDef",
@@ -63,6 +71,8 @@ __all__ = (
     "GetAssetResponseTypeDef",
     "GetDataSetRequestRequestTypeDef",
     "GetDataSetResponseTypeDef",
+    "GetEventActionRequestRequestTypeDef",
+    "GetEventActionResponseTypeDef",
     "GetJobRequestRequestTypeDef",
     "GetJobResponseTypeDef",
     "GetRevisionRequestRequestTypeDef",
@@ -78,6 +88,8 @@ __all__ = (
     "ListDataSetRevisionsResponseTypeDef",
     "ListDataSetsRequestRequestTypeDef",
     "ListDataSetsResponseTypeDef",
+    "ListEventActionsRequestRequestTypeDef",
+    "ListEventActionsResponseTypeDef",
     "ListJobsRequestRequestTypeDef",
     "ListJobsResponseTypeDef",
     "ListRevisionAssetsRequestRequestTypeDef",
@@ -91,6 +103,7 @@ __all__ = (
     "ResponseMetadataTypeDef",
     "RevisionDestinationEntryTypeDef",
     "RevisionEntryTypeDef",
+    "RevisionPublishedTypeDef",
     "S3SnapshotAssetTypeDef",
     "StartJobRequestRequestTypeDef",
     "TagResourceRequestRequestTypeDef",
@@ -99,10 +112,20 @@ __all__ = (
     "UpdateAssetResponseTypeDef",
     "UpdateDataSetRequestRequestTypeDef",
     "UpdateDataSetResponseTypeDef",
+    "UpdateEventActionRequestRequestTypeDef",
+    "UpdateEventActionResponseTypeDef",
     "UpdateRevisionRequestRequestTypeDef",
     "UpdateRevisionResponseTypeDef",
 )
 
+ActionTypeDef = TypedDict(
+    "ActionTypeDef",
+    {
+        "ExportRevisionToS3": "AutoExportRevisionToS3RequestDetailsTypeDef",
+    },
+    total=False,
+)
+
 _RequiredAssetDestinationEntryTypeDef = TypedDict(
     "_RequiredAssetDestinationEntryTypeDef",
     {
@@ -168,6 +191,50 @@ AssetSourceEntryTypeDef = TypedDict(
     },
 )
 
+_RequiredAutoExportRevisionDestinationEntryTypeDef = TypedDict(
+    "_RequiredAutoExportRevisionDestinationEntryTypeDef",
+    {
+        "Bucket": str,
+    },
+)
+_OptionalAutoExportRevisionDestinationEntryTypeDef = TypedDict(
+    "_OptionalAutoExportRevisionDestinationEntryTypeDef",
+    {
+        "KeyPattern": str,
+    },
+    total=False,
+)
+
+
+class AutoExportRevisionDestinationEntryTypeDef(
+    _RequiredAutoExportRevisionDestinationEntryTypeDef,
+    _OptionalAutoExportRevisionDestinationEntryTypeDef,
+):
+    pass
+
+
+_RequiredAutoExportRevisionToS3RequestDetailsTypeDef = TypedDict(
+    "_RequiredAutoExportRevisionToS3RequestDetailsTypeDef",
+    {
+        "RevisionDestination": "AutoExportRevisionDestinationEntryTypeDef",
+    },
+)
+_OptionalAutoExportRevisionToS3RequestDetailsTypeDef = TypedDict(
+    "_OptionalAutoExportRevisionToS3RequestDetailsTypeDef",
+    {
+        "Encryption": "ExportServerSideEncryptionTypeDef",
+    },
+    total=False,
+)
+
+
+class AutoExportRevisionToS3RequestDetailsTypeDef(
+    _RequiredAutoExportRevisionToS3RequestDetailsTypeDef,
+    _OptionalAutoExportRevisionToS3RequestDetailsTypeDef,
+):
+    pass
+
+
 CancelJobRequestRequestTypeDef = TypedDict(
     "CancelJobRequestRequestTypeDef",
     {
@@ -216,6 +283,27 @@ CreateDataSetResponseTypeDef = TypedDict(
     },
 )
 
+CreateEventActionRequestRequestTypeDef = TypedDict(
+    "CreateEventActionRequestRequestTypeDef",
+    {
+        "Action": "ActionTypeDef",
+        "Event": "EventTypeDef",
+    },
+)
+
+CreateEventActionResponseTypeDef = TypedDict(
+    "CreateEventActionResponseTypeDef",
+    {
+        "Action": "ActionTypeDef",
+        "Arn": str,
+        "CreatedAt": datetime,
+        "Event": "EventTypeDef",
+        "Id": str,
+        "UpdatedAt": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 CreateJobRequestRequestTypeDef = TypedDict(
     "CreateJobRequestRequestTypeDef",
     {
@@ -320,6 +408,13 @@ DeleteDataSetRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeleteEventActionRequestRequestTypeDef = TypedDict(
+    "DeleteEventActionRequestRequestTypeDef",
+    {
+        "EventActionId": str,
+    },
+)
+
 DeleteRevisionRequestRequestTypeDef = TypedDict(
     "DeleteRevisionRequestRequestTypeDef",
     {
@@ -337,6 +432,26 @@ DetailsTypeDef = TypedDict(
     total=False,
 )
 
+EventActionEntryTypeDef = TypedDict(
+    "EventActionEntryTypeDef",
+    {
+        "Action": "ActionTypeDef",
+        "Arn": str,
+        "CreatedAt": datetime,
+        "Event": "EventTypeDef",
+        "Id": str,
+        "UpdatedAt": datetime,
+    },
+)
+
+EventTypeDef = TypedDict(
+    "EventTypeDef",
+    {
+        "RevisionPublished": "RevisionPublishedTypeDef",
+    },
+    total=False,
+)
+
 ExportAssetToSignedUrlRequestDetailsTypeDef = TypedDict(
     "ExportAssetToSignedUrlRequestDetailsTypeDef",
     {
@@ -535,6 +650,26 @@ GetDataSetResponseTypeDef = TypedDict(
     },
 )
 
+GetEventActionRequestRequestTypeDef = TypedDict(
+    "GetEventActionRequestRequestTypeDef",
+    {
+        "EventActionId": str,
+    },
+)
+
+GetEventActionResponseTypeDef = TypedDict(
+    "GetEventActionResponseTypeDef",
+    {
+        "Action": "ActionTypeDef",
+        "Arn": str,
+        "CreatedAt": datetime,
+        "Event": "EventTypeDef",
+        "Id": str,
+        "UpdatedAt": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 GetJobRequestRequestTypeDef = TypedDict(
     "GetJobRequestRequestTypeDef",
     {
@@ -742,6 +877,25 @@ ListDataSetsResponseTypeDef = TypedDict(
     },
 )
 
+ListEventActionsRequestRequestTypeDef = TypedDict(
+    "ListEventActionsRequestRequestTypeDef",
+    {
+        "EventSourceId": str,
+        "MaxResults": int,
+        "NextToken": str,
+    },
+    total=False,
+)
+
+ListEventActionsResponseTypeDef = TypedDict(
+    "ListEventActionsResponseTypeDef",
+    {
+        "EventActions": List["EventActionEntryTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListJobsRequestRequestTypeDef = TypedDict(
     "ListJobsRequestRequestTypeDef",
     {
@@ -909,6 +1063,13 @@ class RevisionEntryTypeDef(_RequiredRevisionEntryTypeDef, _OptionalRevisionEntry
     pass
 
 
+RevisionPublishedTypeDef = TypedDict(
+    "RevisionPublishedTypeDef",
+    {
+        "DataSetId": str,
+    },
+)
+
 S3SnapshotAssetTypeDef = TypedDict(
     "S3SnapshotAssetTypeDef",
     {
@@ -1005,6 +1166,40 @@ UpdateDataSetResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredUpdateEventActionRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateEventActionRequestRequestTypeDef",
+    {
+        "EventActionId": str,
+    },
+)
+_OptionalUpdateEventActionRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateEventActionRequestRequestTypeDef",
+    {
+        "Action": "ActionTypeDef",
+    },
+    total=False,
+)
+
+
+class UpdateEventActionRequestRequestTypeDef(
+    _RequiredUpdateEventActionRequestRequestTypeDef, _OptionalUpdateEventActionRequestRequestTypeDef
+):
+    pass
+
+
+UpdateEventActionResponseTypeDef = TypedDict(
+    "UpdateEventActionResponseTypeDef",
+    {
+        "Action": "ActionTypeDef",
+        "Arn": str,
+        "CreatedAt": datetime,
+        "Event": "EventTypeDef",
+        "Id": str,
+        "UpdatedAt": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredUpdateRevisionRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateRevisionRequestRequestTypeDef",
     {
